#
# spec file for package calcurse
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           calcurse
Version:        4.1.0
Release:        2.2
Summary:        Text-based Organizer
License:        BSD-2-Clause
Group:          Productivity/Office/Organizers
Source:         http://calcurse.org/files/calcurse-%{version}.tar.gz
Source1:        %{name}.desktop
Url:            http://calcurse.org
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc
BuildRequires:  gettext
BuildRequires:  gettext-devel
BuildRequires:  glibc-devel
BuildRequires:  libtool
BuildRequires:  make
BuildRequires:  ncurses-devel
BuildRequires:  update-desktop-files

%description
Calcurse is a text-based personal organizer which helps keep track of events
and everyday tasks. It has a calendar and a "todo" list, and puts your
appointments in order. The user interface is configurable, and you can choose
between different color schemes and layouts. All of the commands are
documented within an online help system.

%lang_package

%prep
%setup -q

%build
%configure
%__make %{?_smp_flags}

%install
%makeinstall

%__rm -rf "%{buildroot}%{_datadir}/doc"

%__install -D -m 0644 "%{SOURCE1}" "%{buildroot}%{_datadir}/applications/%{name}.desktop"
%if 0%{?suse_version} > 0
%suse_update_desktop_file -r "%{name}" Office Calendar
%endif

%__mv \
    "%{buildroot}%{_datadir}/locale/en" \
    "%{buildroot}%{_datadir}/locale/en_US"

%find_lang %{name}

%__chmod 0644 AUTHORS COPYING NEWS README

%files
%defattr(-,root,root)
%doc AUTHORS COPYING NEWS README
%doc doc/manual.html
%{_bindir}/calcurse
%{_bindir}/calcurse-caldav
%{_bindir}/calcurse-upgrade
%doc %{_mandir}/man1/calcurse.1*
%{_datadir}/applications/%{name}.desktop

%files lang -f %{name}.lang
%defattr(-,root,root)

%changelog
* Wed Aug  3 2016 dmacvicar@suse.de
- Update to version 4.1.0
  * Hook support: Run scripts before/after loading or saving items. This
    feature can be used to automatically make Git commits or synchronize with a
    server when the data files are written. Example hooks can be found in the
    calcurse source tree.
  * Experimental CalDAV support: The calcurse distribution tarball now includes
    an experimental script called calcurse-caldav that can be used to
    synchronize calcurse with your mobile devices or any other computer. For
    details, please refer to contrib/caldav/README in the calcurse source tree.
  * Support for a filter mode -F that is identical to -G but writes the
    filtered items back to the calcurse data files instead of stdout. Can be
    used to remove certain items from a script. Use with care!
  * New long format specifiers "raw" and "hash".
  * A --daemon command line option to start calcurse in daemon mode.
  * A --quiet command line option to disable system dialogs.
  * Support for todo items with an undefined priority.
  * Support for durations when specifying recurrence end dates.
  * Support for decimal values when specifying durations.
  * Support for UTC times when importing iCal events.
  * Support for sending notifications for all appointments (both flagged and
    unflagged items).
  * The "Add Item" key binding now works from the calendar panel.
  * Week numbers in the monthly view (requested by Hakan Jerning).
  * Fixes to the slice computation (reported by Hakan Jerning).
  * Various fixes to the iCal import and export functionality.
* Tue Mar  3 2015 p.drouand@gmail.com
- Update to version 4.0.0
  * Support for reloading appointments via a key binding and via SIGUSR1
  * The compact mode and default panel options are no longer hidden.
  * A powerful set of new command line options. The new main operations in
    non-interactive mode are --grep and --query. There are filter switches to
    restrict the set of items that are read from the appointments file. All
    old command line options are still supported for backwards compatibility.
  * Support for shorthands such as "tomorrow" or "monday" as date specifiers.
  * Support for dates beyond 2038 on platforms with 64-bit time_t.
  * Several fixes to the user interface.
  * Handle CRLF line endings in iCal files
  * Gracefully handle all day events in iCal imports
  * Retain comments in descriptions and configuration values
  * Support all types of iCal durations
- Remove suse macros as calcurse doesn't build for other distributions
  anyway
* Thu Dec 25 2014 p.drouand@gmail.com
- Update to version 3.2.1
  + Load todo items on startup
  + Do not highlight items on inactive windows.
- TODO file doesn't exist anymore; remove it from %%doc list
- Add COPYING file to %%doc list
* Mon Apr 22 2013 puzel@suse.com
- update to calcurse-3.1.4
  - Do not prompt for a todo after adding an appointment.
  - Close key binding window when reassigning the same key (thanks
    to Michael Smith for submitting a patch).
  - Update copyright ranges.
  - Do not ignore "--datarootdir" in the i18n Makefile.
  - Complete the test-suite even if libfaketime is not present.
  - Add a workaround for broken libfaketime-based tests on 32-bit
    systems (fixes Debian bug #697013).
  - Do not update start time/duration with bogus values if the
    prompt is canceled in edit mode.
  - Fix another corner case of the screen corruption bug (BUG#6).
  - Fix core dump when trying to edit a non-existent item.
  - Display correct welcome messages on startup.
* Sat Dec  8 2012 pascal.bleser@opensuse.org
- update to 3.1.1:
  * fix screen corruption bug
* Wed Dec  5 2012 pascal.bleser@opensuse.org
- update to 3.1.0:
  * Vim-like copy/paste (FR#15). Use the delete key to cut items.
  * Support for entering times in 24 hour format ("2130" instead of "21:30")
  * Compact panel mode (FR#7). This can be enabled using the currently
    undocumented "appearance.compactpanels" configuration setting.
  * Configurable default view (FR#19). The default view can be changed using
    the currently undocumented "appearance.defaultpanel" configuration setting.
  * "-D" and "-c" can now be used simultaneously, whereby "-c" has precedence
    over "-D".
  * Cache monthly view to speed up browsing.
  * Sort `calcurse -d` output by time
  * Fix a critical data corruption bug
  * Fix screen corruption
  * No longer show the calcurse screen in the editor/pager when the window is
    resized
  * Calculate busy slices correctly if (recurrent) appointments with a duration
    of more than 24 hours are used.
  * Fix a core dump that occurred if the main window was too small.
  * Several translation updates.
* Sun Jul  1 2012 pascal.bleser@opensuse.org
- update to 3.0.0:
  * full UTF-8 support
  * format strings for printing items in non-interactive mode have been
    introduced
  * support for vim-style count prefixes for displacement keys
  * duration strings are now much more powerful
  * extended duration strings, such as "+3:10" or "+1d20h5m", can be used
  * new feature allows piping items to external commands
  * there are keybindings to jump to the previous/next month/year
  * lots of internal changes have been made
  * note that you will need to run "calcurse-upgrade" after upgrading, since
    the configuration file format has changed
* Sun Jul  1 2012 puzel@suse.com
- update to calcurse-3.0.0
  - New features:
  - Full UTF-8 support.
  - Much more powerful formatting options for printing items in
    non-interactive mode. Format strings can be specified using
    "--format-apt", "--format-event", "--format-recur-apt" and
    "--format-recur-event".
  - Support for vim-style count prefixes for displacement keys.
  - Powerful duration strings: Allows using extended duration
    strings, such as "+3:10" or "+1d20h5m".
  - A feature that allows piping items to external commands.
  - New key bindings to jump to the previous/next month/year.
  - A new configuration file format. `calcurse-upgrade` can be used
    to convert existing configuration files.
  - Several performance improvements.
  - Notes are now stored using hash-based file names which results
    in lower disk space usage.
  - A test suite that can be used to test the core functionality of
    calcurse.
  - "-D" and "-c" can now be used simultaneously, whereby "-c" has
    precedence over "-D".
  - A "--read-only" command line option to discard all changes to
    data files.
  - Bug fixes:
  - Do not hardcode paths to the default editor/pager. Rely on the
    "$PATH" variable instead.
  - Update the number of todo items when importing an iCal file to
    prevent some items from being inaccessible.
  - Fix a segmentation fault when importing iCal data (reported by
    Andraz Levstik).
  - Format the "DURATION" field properly on iCal export. Use
    days/hours/minutes/seconds instead of seconds (reported and
    fixed by Jerome Pinot).
  - Do not localize dates in pcal exports (reported by Baptiste
    Jonglez).
* Thu Dec 15 2011 coolo@suse.com
- fix license to be in spdx.org format
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Fri Sep 16 2011 puzel@suse.com
- update to 2.9.2
  - Handle iCal line folding correctly.
  - Introduce a configure option to completely exclude the
    documentation subdirectory from the build process
    ("--disable-docs").
- changes in 2.9.1
  - Keep the order of events across restarts (reported by Alan).
  - Fix the build process when disabling documentation generation.
  - Avoid flickering on window resize.
  - Avoid a segfault when resizing the calcurse window.
  - Add missing documentation for the "backword-kill-word" line
    editing function.
  - Honor the "TMPDIR" environment variable instead of using
    hardcoded paths for temporary files (reported by Erik Saule).
  - Fix pager invocation when showing the log file during an import
    (reported by Andraz Levstik).
  - Accept resource parameters in iCal import. Accept additional
    parameters such as language parameters (reported by Andraz
    Levstik).
  - Sync the notification item after editing or pasting an
    appointment. This ensures the information in the notification
    bar as well as the countdown for the notification daemon are
    always up-to-date (reported by Andraz Levstik).
  - Fix recurrent appointment notification.
  - Fix flagging of regular appointments.
  - Fix sort order when using command line options to display
    upcoming appointments and events (reported by Erik Saule).
* Sun May 29 2011 pascal.bleser@opensuse.org
- update to 2.9.0:
  * add support for short form dates
  * add "backword-kill-word" line editing function
  * add automatic removal of notes that are empty after editing
  * add a Russian translation
  * fixes a segfault when resizing the help window were fixed
  * fixes lock file issues
  * fixes parsing of appointment end times that date back
* Wed Jan 12 2011 puzel@novell.com
- minor spec cleanup (by Pascal)
* Sat Nov 13 2010 pascal.bleser@opensuse.org
- drop calcurse-fix_missing_return_in_nonvoid_function.patch, has been merged upstream
* Sun May 30 2010 pascal.bleser@opensuse.org
- update to 2.8:
  * adds a weekly calendar view that displays the week number and colored
    slices indicating appointment times
  * the side bar width can now be customized by the user
  * some bugs were addressed in this release, the most important being
    incorrect calculation of recurrent dates after a turn of year
* Sat Aug 29 2009 pascal.bleser@opensuse.org
- update to 2.7:
  * a daemon was implemented so that reminders can now be sent while calcurse
    is running in the background
  * a new '--status' command line option was added for displaying information
    about already running instances
  * important bugs related to ical import and export were addressed in this
    release
* Sun Jul 12 2009 pascal.bleser@opensuse.org
- update to 2.6
* Sat Dec 27 2008 guru@unixtech.be
- update to 2.4:
  * add ability to define its own key bindings.
  * the layout configuration menu was redesigned to become more user-friendly
  * important bugs were addressed in this release: a memory leak due to a
    wrong use of the pthread library was fixed, and a possible freeze when
    deleting an appointment's note does not appear anymore
  * regarding data export, exception dates are now properly ignored
  * a daylight saving time unwanted offset is not added anymore
* Wed Oct 15 2008 guru@unixtech.be
- update to 2.3:
  * adds the ability to import data from the iCalendar format as defined in
    RFC 2445
* Fri Aug 29 2008 guru@unixtech.be
- added Authors:
- update to 2.2:
  * add ability to export data to pcal format and thus to produce nice-looking
    Postscript output for printing
  * new command line arguments were added that allow you to use an alternative
    data directory, and to be more flexible when specifying the range of dates
    to be considered when displaying appointments and events
  * new key bindings ease movements in the calendar
- changes from 2.1:
  * fixed bug in changing of todo priority, which could result in a segfault
    in some cases
  * display note contents in non-interactive mode
  * date formats are now user-configurable
  * the Italian manual translation was added
* Sun Mar  2 2008 guru@unixtech.be
- new upstream version
* Wed Oct 24 2007 guru@unixtech.be
- moved to openSUSE Build Service
- new upstream version
* Sat Jan 20 2007 guru@unixtech.be
- new upstream version
* Sat Aug 26 2006 guru@unixtech.be
- new upstream version
* Tue May 30 2006 guru@unixtech.be
- new upstream version
* Sun Apr 23 2006 guru@unixtech.be
- new upstream version
- rewrote spec file
- pass -j to make
- removed Packager and Distribution, injected by rpmmacros
- binary stripping on SUSE < 9.3
